@@ -26,6 +26,7 @@ from comicapi.genericmetadata import GenericMetadata
 from comictaggerlib.coverimagewidget import CoverImageWidget
 from comictaggerlib.resulttypes import IssueResult, MultipleMatch
 from comictaggerlib.settings import ComicTaggerSettings
+from comictaggerlib.ui import ui_path
 from comictaggerlib.ui.qtutils import reduce_widget_font_size
 
 logger = logging.getLogger(__name__)
@@ -44,7 +45,7 @@ class AutoTagMatchWindow(QtWidgets.QDialog):
     ) -> None:
         super().__init__(parent)
 
-        uic.loadUi(ComicTaggerSettings.get_ui_file("matchselectionwindow.ui"), self)
+        uic.loadUi(ui_path / "matchselectionwindow.ui", self)
 
         self.settings = settings
 
