@@ -30,6 +30,7 @@ from comicapi.genericmetadata import GenericMetadata
 from comictaggerlib.cbltransformer import CBLTransformer
 from comictaggerlib.comicvinetalker import ComicVineTalker, ComicVineTalkerException
 from comictaggerlib.filerenamer import FileRenamer, get_rename_dir
+from comictaggerlib.graphics import graphics_path
 from comictaggerlib.issueidentifier import IssueIdentifier
 from comictaggerlib.resulttypes import IssueResult, MultipleMatch, OnlineMatchResults
 from comictaggerlib.settings import ComicTaggerSettings
@@ -214,7 +215,7 @@ def process_file_cli(
 ) -> None:
     batch_mode = len(opts.file_list) > 1
 
-    ca = ComicArchive(filename, settings.rar_exe_path, ComicTaggerSettings.get_graphic("nocover.png"))
+    ca = ComicArchive(filename, settings.rar_exe_path, str(graphics_path / "nocover.png"))
 
     if not os.path.lexists(filename):
         logger.error("Cannot find %s", filename)
@@ -525,7 +526,10 @@ def process_file_cli(
         suffix = ""
         if not opts.dryrun:
             # rename the file
-            ca.rename(utils.unique_file(full_path))
+            try:
+                ca.rename(utils.unique_file(full_path))
+            except OSError:
+                logger.exception("Failed to rename comic archive: %s", ca.path)
         else:
             suffix = " (dry-run, no change)"
 
