@@ -407,6 +407,10 @@ class ComicVineTalker:
 
         self.repair_urls(filtered_issues_result)
 
+        cvc = ComicCacher()
+        for c in filtered_issues_result:
+            cvc.add_volume_issues_info(self.source_name, c["volume"]["id"], [c])
+
         return filtered_issues_result
 
     def fetch_issue_data(self, series_id: int, issue_number: str, settings: ComicTaggerSettings) -> GenericMetadata:
@@ -671,7 +675,7 @@ class ComicVineTalker:
 
     def fetch_alternate_cover_urls(self, issue_id: int, issue_page_url: str) -> list[str]:
         url_list = self.fetch_cached_alternate_cover_urls(issue_id)
-        if url_list is not None:
+        if url_list:
             return url_list
 
         # scrape the CV issue page URL to get the alternate cover URLs
